"""Integration modules for Prompt Decorators.

This package contains modules for integrating Prompt Decorators with
various frameworks, protocols, and platforms.
"""

# Make the mcp module directly accessible
from prompt_decorators.integrations import mcp

__all__ = ["mcp"]
